@@ -4,6 +4,7 @@
 This module document the YAML Job Args for Pharbers jobs
 """
 import boto3
+import pandas as pd
 import string
 
 
@@ -24,7 +25,10 @@ class PhS3(object):
             Key=s3_path
         )
         # return string.split(response["Body"].read().decode(), "\n")
-        return str.split(response["Body"].read().decode(), "\n")
+        try:
+            return str.split(response["Body"].read().decode(), "\n")
+        except TypeError:
+            return str.split(response["Body"].read().decode(encoding="utf-8"), "\n")
 
     def copy_object_2_file(self, bk_name, s3_path, local_path):
         f = open(local_path, "w")
@@ -39,5 +43,8 @@ class PhS3(object):
             Filename=local_path
         )
 
+    def get_excel_from_s3(self, s3_path):
+        return pd.read_excel(s3_path)
+
 
 s3 = PhS3()
